#[non_exhaustive]pub struct PossiblyRedactedRoomPolicyEventContent {
pub via: Option<OwnedServerName>,
pub public_keys: Option<BTreeMap<SigningKeyAlgorithm, Base64>>,
}Expand description
The possibly redacted form of RoomPolicyEventContent.
This type is used when it’s not obvious whether the content is redacted or not.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.via: Option<OwnedServerName>The server name to use as a Policy Server.
MUST have a joined user in the room.
public_keys: Option<BTreeMap<SigningKeyAlgorithm, Base64>>The public keys for the Policy Server.
MUST contain at least ed25519.